Place - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Place

A `betty.model.ancestry.Places` describes a location or an area in the world, such as a country, town, lake, or building.

## Fields

Places inherit from:

- Privacy

`encloses` (optional `Place`)

  Another place this place encloses or contains.

`enclosed_by` (optional `Place`)

  Another place this place is enclosed or contained by.

`events` (iterable of Event)

  The events that took place here.

`files` (iterable of File)

  The files attached to this place.

`id` (`str`)

  The place’s own entity ID.

`links` (iterable of Link)

  The external links for this place.

`names` (iterable of PlaceName)

  The place’s names.